//UpdateGoogle-OnSave v1.0
 
//Purpose:
//Creates or updates a Google event on the specified calendar based on a source event
 
//Action Type: On Event Save
//Prevent Default Action: Yes
 
//More info on Before Event Save actions and objects here:
//https://docs.dayback.com/article/20-event-actions
 
//configuration variables
//googleId field id
//This will be a custom field id you've set up to store the google event's id
var googleIdField = '1569954181553-8437484076';
 
//match a resource name to a google calendar by name
var resourceMap = {
  'Jason Young' : 'Jason Calendly',
  'John Sindelar' : 'John Calendly',
};
 
//----------- You shouldn’t need to edit below this line -------------------
 
//determine our target GoogleCalendar
var calendarName = resourceMap[event.resource[0]];
var calendarId = getCalendarIdFromName(calendarName);
 
//validate id
if(!calendarId){
  //can't find the target google calendar.
  utilities.showModal('Error', 'DayBack can\'t find the target calendar ' + calendarName + '. Are you logged into Google?', 'OK', cancelButton);
}
else{
  //we have a target calendar, proceed
  updateGoogle(calendarId);
}
 
//functions
 
function updateGoogle(calendarId){
 
  //set request parameters
  var params = {};
  var settings = gBk.settings;
  params.access_token = settings.token;
 
  //create request based on our source event
  var request = {};
  request.description = event.description ? event.description : '';
  request.location = event.location ? event.location : '';
  request.summary = event.titleEdit ? event.titleEdit : '';
  request.end = {
    'dateTime': null,
    'date': null
  };
  request.start = {
    'dateTime': null,
    'date': null
  };
  if (event.allDay) {
    request.start.date = event.start.format('YYYY-MM-DD');
    request.end.date = event.end.format('YYYY-MM-DD');
  } else {
    request.start.dateTime = event.start.format();
    request.end.dateTime = event.end.format();
    request.start.timeZone = settings.timezone.value;
    request.end.timeZone = settings.timezone.value;
  }
  //write status and resource for DayBack
  request.extendedProperties = {};
  request.extendedProperties.shared = {};
  request.extendedProperties.shared.dBk_resource = JSON.stringify(event.resource);
  request.extendedProperties.shared.dBk_status = JSON.stringify(event.status);
 
  //create PATCH or POST depending on if we have a google event id already
  if (event[googleIdField]) {
    gBk.ajaxRequest({
      url: 'https://www.googleapis.com/calendar/' + settings.calendarApi + '/calendars/' + encodeURIComponent(calendarId) + '/events/' + encodeURIComponent(event[googleIdField]),
      type: 'PATCH',
      params: params,
      data: request,
      onSuccess: function(response) {
        processResponse(response);
      },
      onError: function(error) {
        utilities.showModal('Google Error', 'Code: ' + error.code, 'OK', cancelButton);
      },
    });
  }
  else {
    gBk.ajaxRequest({
      url: 'https://www.googleapis.com/calendar/' + settings.calendarApi + '/calendars/' + encodeURIComponent(calendarId) + '/events/',
      type: 'POST',
      params: params,
      data: request,
      onSuccess: function(response) {
        processResponse(response);
      },
      onError: function(error) {
        utilities.showModal('Google Error', 'Code: ' + error.code, 'OK', cancelButton);
      },
    });
  }
 
  function processResponse(data) {
    //write our google id back to our source event
    changesObject[googleIdField] = data.id;
    action.callbacks.confirm();
  }
 
}
 
function cancelButton(){
    action.callbacks.cancel();
}
 
function getCalendarIdFromName(calendarName){
  var calendars = seedcodeCalendar.get('schedules');
  for ( var i = 0 ; i < calendars.length ; i++){
    if( calendars[i].sourceTypeID===3 && calendars[i].name===calendarName ) {
      return calendars[i].id;
    }
  }
  return false;
}